summaryrefslogtreecommitdiff
path: root/net/asterisk14
diff options
context:
space:
mode:
authorMaxim Sobolev <sobomax@FreeBSD.org>2008-10-20 17:26:22 +0000
committerMaxim Sobolev <sobomax@FreeBSD.org>2008-10-20 17:26:22 +0000
commit96b184e9dcdd6e89cfbdfc2a1c4f7c2f19614a94 (patch)
tree38f269a3c24183878320940480fd0dc4fd42fb23 /net/asterisk14
parent- Unbreak under certain conditions (disable SSE and MMX) (diff)
Make patch sutrable for integration with vendor by putting back
#ifdef that we have had no business of removing in the first place. Don't bump PORTREVISION since it makes no difference for the compiled package.
Notes
Notes: svn path=/head/; revision=221847
Diffstat (limited to 'net/asterisk14')
-rw-r--r--net/asterisk14/files/patch-main::utils.c18
1 files changed, 7 insertions, 11 deletions
diff --git a/net/asterisk14/files/patch-main::utils.c b/net/asterisk14/files/patch-main::utils.c
index 9bba111de434..7f2f1495d714 100644
--- a/net/asterisk14/files/patch-main::utils.c
+++ b/net/asterisk14/files/patch-main::utils.c
@@ -1,20 +1,16 @@
---- main/utils.c.orig 2008-05-29 19:20:16.000000000 +0200
-+++ main/utils.c 2008-10-03 21:36:14.000000000 +0200
-@@ -914,8 +914,7 @@
+
+$FreeBSD$
+
+--- main/utils.c.orig
++++ main/utils.c
+@@ -914,8 +914,8 @@
pthread_attr_init(attr);
}
-#ifdef __linux__
- /* On Linux, pthread_attr_init() defaults to PTHREAD_EXPLICIT_SCHED,
++#if defined(__linux__) || defined(__FreeBSD__)
+ /* On Linux and FreeBSD, pthread_attr_init() defaults to PTHREAD_EXPLICIT_SCHED,
which is kind of useless. Change this here to
PTHREAD_INHERIT_SCHED; that way the -p option to set realtime
priority will propagate down to new threads by default.
-@@ -924,7 +923,6 @@
- the priority afterwards with pthread_setschedparam(). */
- if ((errno = pthread_attr_setinheritsched(attr, PTHREAD_INHERIT_SCHED)))
- ast_log(LOG_WARNING, "pthread_attr_setinheritsched: %s\n", strerror(errno));
--#endif
-
- if (!stacksize)
- stacksize = AST_STACKSIZE;